Function rust_utils::utils::get_filename
source · pub fn get_filename<D: Into<PathBuf>>(dir: D) -> StringExpand description
Get the name of the file/directory from a file path
Returns an empty string if there is no file name
pub fn get_filename<D: Into<PathBuf>>(dir: D) -> StringGet the name of the file/directory from a file path
Returns an empty string if there is no file name