Function rust_utils::utils::get_parent
source · pub fn get_parent<D: Into<PathBuf>>(dir: D) -> StringExpand description
Gets the parent directory from a file path
Returns the current path if there is no parent
pub fn get_parent<D: Into<PathBuf>>(dir: D) -> StringGets the parent directory from a file path
Returns the current path if there is no parent